import { IClozeDeletion } from "../interfaces/IClozeDeletion";
import { IClozeFormatter } from "../interfaces/IClozeFormatter";
import { IClozeNote } from "../interfaces/IClozeNote";
import { IClozePattern } from "../interfaces/IClozePattern";
import { ClozeTypeEnum } from "./ClozeTypeEnum";
/**
 * Class ClozeNote
 *
 * This class is not meant to be used directly. It serves as a base implementation
 * for common methods used in other implementations of ClozeNote.
 */
export declare abstract class ClozeNote<T extends IClozeDeletion> implements IClozeNote {
    protected _raw: string;
    protected _clozeDeletions: T[];
    protected _numCards: number;
    /**
     * Creates a new ClozeNote instance.
     *
     * @param raw The raw text of the cloze note before processing.
     */
    constructor(raw: string, patterns: IClozePattern[]);
    abstract get clozeType(): ClozeTypeEnum;
    protected abstract initParsing(rawNote: string, patterns: IClozePattern[]): {
        clozeDeletions: T[];
        numCards: number;
    };
    get raw(): string;
    get numCards(): number;
    abstract getCardFront(cardIndex: number, formatter?: IClozeFormatter): string;
    abstract getCardBack(cardIndex: number, formatter?: IClozeFormatter): string;
}
