"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ClozeNoteClassic = void 0;
const ClozeNote_1 = require("./ClozeNote");
const utils_1 = require("./utils");
const ClozeTypeEnum_1 = require("./ClozeTypeEnum");
class ClozeNoteClassic extends ClozeNote_1.ClozeNote {
    constructor(raw, patterns) {
        super(raw, patterns);
    }
    get clozeType() {
        return ClozeTypeEnum_1.ClozeTypeEnum.CLASSIC;
    }
    initParsing(rawNote, patterns) {
        let clozeDeletions = [];
        let numCards = 0;
        patterns.forEach((pattern) => {
            const regex = pattern.getClozeRegex(ClozeTypeEnum_1.ClozeTypeEnum.CLASSIC);
            let match;
            while (match = regex.exec(rawNote)) {
                if (!match.seq) {
                    break;
                }
                let newCloze = {
                    raw: match.raw,
                    answer: match.answer,
                    seq: parseInt(match.seq),
                    hint: match.hint
                };
                clozeDeletions.push(newCloze);
                // Get the max seq
                if (numCards < newCloze.seq) {
                    numCards = newCloze.seq;
                }
            }
        });
        return { clozeDeletions, numCards };
    }
    getCardFront(cardIndex, formatter) {
        if (cardIndex >= this._numCards || cardIndex < 0) {
            throw new Error(`Card ${cardIndex} does not exist`);
        }
        if (!formatter) {
            formatter = new utils_1.simpleFormatter();
        }
        let frontText = this.raw;
        for (const deletion of this._clozeDeletions) {
            if (deletion.seq !== cardIndex + 1) {
                frontText = frontText.replace(deletion.raw, deletion.answer); // Just show
                continue;
            }
            frontText = frontText.replace(deletion.raw, formatter.asking(deletion.answer, deletion.hint)); // Hide asked cloze
        }
        return frontText;
    }
    getCardBack(cardIndex, formatter) {
        if (cardIndex >= this._numCards || cardIndex < 0) {
            throw new Error(`Card ${cardIndex} does not exist`);
        }
        if (!formatter) {
            formatter = new utils_1.simpleFormatter();
        }
        let backText = this.raw;
        for (const deletion of this._clozeDeletions) {
            if (deletion.seq === cardIndex + 1) {
                backText = backText.replace(deletion.raw, formatter.showingAnswer(deletion.answer, deletion.hint)); // Show as answer
            }
            else {
                backText = backText.replace(deletion.raw, deletion.answer); // Just show
            }
        }
        return backText;
    }
}
exports.ClozeNoteClassic = ClozeNoteClassic;
